package com.alterdekim.hearthhack.config;

import com.alterdekim.hearthhack.handler.BattleNetSocketHandler;
import com.alterdekim.hearthhack.parser.BattleNetSerializerDeserializer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.integration.config.EnableIntegration;
import org.springframework.integration.dsl.IntegrationFlow;
import org.springframework.integration.ip.dsl.Tcp;
import org.springframework.integration.ip.dsl.TcpInboundGatewaySpec;
import org.springframework.integration.ip.dsl.TcpServerConnectionFactorySpec;

@Slf4j
@Configuration
@EnableIntegration
public class TcpServerSocketConfiguration {

    private final int socketPort = 1119;

    @Bean
    public IntegrationFlow server(BattleNetSocketHandler serverSocketHandler) {
        TcpServerConnectionFactorySpec connectionFactory =
                Tcp.netServer(socketPort)
                        .deserializer(new BattleNetSerializerDeserializer())
                        .serializer(new BattleNetSerializerDeserializer())
                        .soTcpNoDelay(true);

        TcpInboundGatewaySpec inboundGateway =
                Tcp.inboundGateway(connectionFactory);

        return IntegrationFlow
                .from(inboundGateway)
                .handle(serverSocketHandler::handleMessage)
                .get();
    }

    @Bean
    public BattleNetSocketHandler serverSocketHandler() {
        return new BattleNetSocketHandler();
    }
}