package com.alterdekim.services;

import com.alterdekim.Connection;
import com.alterdekim.Protocol;
import com.alterdekim.hearthhack.util.BattleNetPacket;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class FriendsService extends Service {

    private static final Logger log = LoggerFactory.getLogger(FriendsService.class);

    public FriendsService(String export_name) {
        super(export_name);
    }

    @Override
    public void process(BattleNetPacket packet, Connection conn) throws Exception {
        switch (packet.getHeader().getMethodId()) {
            case 1:
                //Protocol.SubscribeToFriendsRequest subscribeToFriendsRequest = Protocol.SubscribeToFriendsRequest.parseFrom(packet.getBody());

                if( packet.getHeader().getToken() == 6 ) {
                    Protocol.SubscribeToFriendsResponse subscribeToFriendsResponse = Protocol.SubscribeToFriendsResponse.newBuilder()
                            .setMaxFriends(200)
                            .setMaxReceivedInvitations(200)
                            .setMaxSentInvitations(200)
                            .addRole(Protocol.Role.newBuilder()
                                    .setId(1)
                                    .setName("battle_tag_friend")
                                    .build())
                            .addRole(Protocol.Role.newBuilder()
                                    .setId(2)
                                    .setName("real_id_friend")
                                    .build())
                            .build();

                    Protocol.Header header = Protocol.Header.newBuilder()
                            .setServiceId(254)
                            .setStatus(0)
                            .setToken(packet.getHeader().getToken())
                            .setSize(subscribeToFriendsResponse.getSerializedSize())
                            .setObjectId(0)
                            .build();

                    conn.send(new BattleNetPacket(header, subscribeToFriendsResponse.toByteArray()));
                } else if( packet.getHeader().getToken() == 7 ) {
                    Protocol.Header header = Protocol.Header.newBuilder()
                            .setServiceId(254)
                            .setStatus(0)
                            .setToken(packet.getHeader().getToken())
                            .setSize(0)
                            .setObjectId(0)
                            .build();

                    conn.send(new BattleNetPacket(header, new byte[0]));
                }
                break;
            default:
                log.error("Can't process weird FriendsService method: " + packet.getHeader().getMethodId());
                break;
        }
    }
}